pub struct AsyncMutexGuard<'a, T: 'a> { /* private fields */ }Trait Implementations
Sourceimpl<'a, T> Deref for AsyncMutexGuard<'a, T>
impl<'a, T> Deref for AsyncMutexGuard<'a, T>
Sourceimpl<'a, T> DerefMut for AsyncMutexGuard<'a, T>
impl<'a, T> DerefMut for AsyncMutexGuard<'a, T>
Sourceimpl<T> Drop for AsyncMutexGuard<'_, T>
If an AsyncMutexGuard get’s dropped we need to wake the Futures that might hav registered themself and
are waiting to aquire the lock.
impl<T> Drop for AsyncMutexGuard<'_, T>
If an AsyncMutexGuard get’s dropped we need to wake the Futures that might hav registered themself and
are waiting to aquire the lock.