pub struct AsyncReadLockGuard<'a, T: 'a> { /* private fields */ }Trait Implementations
Sourceimpl<'a, T> Deref for AsyncReadLockGuard<'a, T>
impl<'a, T> Deref for AsyncReadLockGuard<'a, T>
Sourceimpl<T> Drop for AsyncReadLockGuard<'_, T>
If an AsyncReadLockGuard get’s dropped we need to wake the Futures that might have registered themself and
are waiting to aquire the lock.
impl<T> Drop for AsyncReadLockGuard<'_, T>
If an AsyncReadLockGuard get’s dropped we need to wake the Futures that might have registered themself and
are waiting to aquire the lock.