AsyncSemaphore

Struct AsyncSemaphore 

pub struct AsyncSemaphore { /* private fields */ }

Implementations

Source

impl AsyncSemaphore

pub fn new(initial: u32) -> Self

pub async fn down(&self)

pub fn up(&self)

when increasing the AsyncSemaphore we will increase the embedded Semaphore and notify the next waiter in the list that previously did not got the chance to decrease the Semaphore