pub struct AsyncWriteLockGuard<'a, T: 'a> { /* private fields */ }Trait Implementations
Sourceimpl<'a, T> Deref for AsyncWriteLockGuard<'a, T>
impl<'a, T> Deref for AsyncWriteLockGuard<'a, T>
Sourceimpl<'a, T> DerefMut for AsyncWriteLockGuard<'a, T>
impl<'a, T> DerefMut for AsyncWriteLockGuard<'a, T>
Sourceimpl<T> Drop for AsyncWriteLockGuard<'_, T>
If an AsyncWriteLockGuard get’s dropped we need to wake the Futures that might have registered themself and
are waiting to aquire the lock.
impl<T> Drop for AsyncWriteLockGuard<'_, T>
If an AsyncWriteLockGuard get’s dropped we need to wake the Futures that might have registered themself and
are waiting to aquire the lock.