ReadLockGuard

Struct ReadLockGuard 

pub struct ReadLockGuard<'a, T: ?Sized + 'a> { /* private fields */ }
Result of aquiring read access to the data using read on the data lock. If the result goes out of scope the read lock is released.