Semaphore

Struct Semaphore 

#[repr(C, align(16))]
pub struct Semaphore { /* private fields */ }
Simple counting blocking or non-blocking lock

Implementations

Source

impl Semaphore

pub const fn new(initial: u32) -> Semaphore

Instantiate a new semaphore with a given initial value

Example
    let mut sema = Semaphore::new(5); // semaphore could be used/aquired 5 times
pub fn up(&self)

increase the inner count of a semaphore allowing it to be used as many times as the inner counters value

Example
    let mut sema = Semaphore::new(0);
    sema.up(); // the counter of the semaphore will be increased
pub fn down(&self)

decrease the inner count of a semaphore. This blocks the current core if the current count is 0 and could not beeing decreased. For an unblocking operation use Semaphore::try_down

Example
    let sema = Semaphore::new(0);
    sema.down();
    // if we reache this line, we have used the semaphore and decreased the counter by 1
pub fn try_down(&self) -> Result<(), ()>

try to decrease a semaphore for usage. Returns [value@Ok] if the semaphore could be used.

Example
    let sema = Semaphore::new(0);
    if sema.try_down().is_ok() {
        // do something... the counter of the semaphore has been decreased by 1
    }