pub struct MutexGuard<'a, T: ?Sized + 'a> { /* private fields */ }Expand description
The MutexGuard is the result of successfully aquiring the mutual exclusive lock for the interior data. If this guard goes ot of scope the lock will be released